from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsStatusType0AnyOfType0Item(str, Enum):
    ACQUIRED = "acquired"
    ACTIVE = "active"
    CLOSED = "closed"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_employment_type_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0
  from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_country_location_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0
  from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_seniority_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0
  from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_standard_industries_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0
  from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_job_location_type_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0
  from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_puree_job_functions_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0





T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0")



@_attrs_define
class TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0:
    """ 
        Attributes:
            total_count (float):
            seniority_stats
                (Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0', None,
                Unset]):
            employment_type_stats
                (Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0',
                None, Unset]):
            country_location_stats
                (Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0',
                None, Unset]):
            puree_job_functions_stats
                (Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0',
                None, Unset]):
            standard_industries_stats
                (Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0',
                None, Unset]):
            job_location_type_stats
                (Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0',
                None, Unset]):
     """

    total_count: float
    seniority_stats: Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0', None, Unset] = UNSET
    employment_type_stats: Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0', None, Unset] = UNSET
    country_location_stats: Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0', None, Unset] = UNSET
    puree_job_functions_stats: Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0', None, Unset] = UNSET
    standard_industries_stats: Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0', None, Unset] = UNSET
    job_location_type_stats: Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_employment_type_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_country_location_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_seniority_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_standard_industries_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_job_location_type_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_puree_job_functions_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0
        total_count = self.total_count

        seniority_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.seniority_stats, Unset):
            seniority_stats = UNSET
        elif isinstance(self.seniority_stats, TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0):
            seniority_stats = self.seniority_stats.to_dict()
        else:
            seniority_stats = self.seniority_stats

        employment_type_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.employment_type_stats, Unset):
            employment_type_stats = UNSET
        elif isinstance(self.employment_type_stats, TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0):
            employment_type_stats = self.employment_type_stats.to_dict()
        else:
            employment_type_stats = self.employment_type_stats

        country_location_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.country_location_stats, Unset):
            country_location_stats = UNSET
        elif isinstance(self.country_location_stats, TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0):
            country_location_stats = self.country_location_stats.to_dict()
        else:
            country_location_stats = self.country_location_stats

        puree_job_functions_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.puree_job_functions_stats, Unset):
            puree_job_functions_stats = UNSET
        elif isinstance(self.puree_job_functions_stats, TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0):
            puree_job_functions_stats = self.puree_job_functions_stats.to_dict()
        else:
            puree_job_functions_stats = self.puree_job_functions_stats

        standard_industries_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.standard_industries_stats, Unset):
            standard_industries_stats = UNSET
        elif isinstance(self.standard_industries_stats, TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0):
            standard_industries_stats = self.standard_industries_stats.to_dict()
        else:
            standard_industries_stats = self.standard_industries_stats

        job_location_type_stats: Union[None, Unset, dict[str, Any]]
        if isinstance(self.job_location_type_stats, Unset):
            job_location_type_stats = UNSET
        elif isinstance(self.job_location_type_stats, TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0):
            job_location_type_stats = self.job_location_type_stats.to_dict()
        else:
            job_location_type_stats = self.job_location_type_stats


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "total_count": total_count,
        })
        if seniority_stats is not UNSET:
            field_dict["seniority_stats"] = seniority_stats
        if employment_type_stats is not UNSET:
            field_dict["employment_type_stats"] = employment_type_stats
        if country_location_stats is not UNSET:
            field_dict["country_location_stats"] = country_location_stats
        if puree_job_functions_stats is not UNSET:
            field_dict["puree_job_functions_stats"] = puree_job_functions_stats
        if standard_industries_stats is not UNSET:
            field_dict["standard_industries_stats"] = standard_industries_stats
        if job_location_type_stats is not UNSET:
            field_dict["job_location_type_stats"] = job_location_type_stats

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_employment_type_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_country_location_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_seniority_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_standard_industries_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_job_location_type_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0
        from ..models.text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0_puree_job_functions_stats_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0
        d = dict(src_dict)
        total_count = d.pop("total_count")

        def _parse_seniority_stats(data: object) -> Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                seniority_stats_type_0 = TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0.from_dict(data)



                return seniority_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0SeniorityStatsType0', None, Unset], data)

        seniority_stats = _parse_seniority_stats(d.pop("seniority_stats", UNSET))


        def _parse_employment_type_stats(data: object) -> Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                employment_type_stats_type_0 = TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0.from_dict(data)



                return employment_type_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0EmploymentTypeStatsType0', None, Unset], data)

        employment_type_stats = _parse_employment_type_stats(d.pop("employment_type_stats", UNSET))


        def _parse_country_location_stats(data: object) -> Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                country_location_stats_type_0 = TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0.from_dict(data)



                return country_location_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0CountryLocationStatsType0', None, Unset], data)

        country_location_stats = _parse_country_location_stats(d.pop("country_location_stats", UNSET))


        def _parse_puree_job_functions_stats(data: object) -> Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                puree_job_functions_stats_type_0 = TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0.from_dict(data)



                return puree_job_functions_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0PureeJobFunctionsStatsType0', None, Unset], data)

        puree_job_functions_stats = _parse_puree_job_functions_stats(d.pop("puree_job_functions_stats", UNSET))


        def _parse_standard_industries_stats(data: object) -> Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                standard_industries_stats_type_0 = TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0.from_dict(data)



                return standard_industries_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0StandardIndustriesStatsType0', None, Unset], data)

        standard_industries_stats = _parse_standard_industries_stats(d.pop("standard_industries_stats", UNSET))


        def _parse_job_location_type_stats(data: object) -> Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_location_type_stats_type_0 = TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0.from_dict(data)



                return job_location_type_stats_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataCompaniesItemLiJobPostsStatsType0JobLocationTypeStatsType0', None, Unset], data)

        job_location_type_stats = _parse_job_location_type_stats(d.pop("job_location_type_stats", UNSET))


        text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0 = cls(
            total_count=total_count,
            seniority_stats=seniority_stats,
            employment_type_stats=employment_type_stats,
            country_location_stats=country_location_stats,
            puree_job_functions_stats=puree_job_functions_stats,
            standard_industries_stats=standard_industries_stats,
            job_location_type_stats=job_location_type_stats,
        )


        text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0.additional_properties = d
        return text_to_combined_search_response_200_output_data_companies_item_li_job_posts_stats_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.poll_combined_search_body_entity_type import PollCombinedSearchBodyEntityType
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="PollCombinedSearchBody")



@_attrs_define
class PollCombinedSearchBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            entity_type (PollCombinedSearchBodyEntityType): Whether you want to find the companies or profiles that your
                search returned. Profiles returned works on the companies that are saved with given search criteria
            search_id (str): The search id returned by the combined search endpoint
            cursor (Union[None, Unset, str]): An optional cursor to start the pagination from
            page_size (Union[Unset, int]): The number of items to return on this page Default: 25.
     """

    api_key: str
    entity_type: PollCombinedSearchBodyEntityType
    search_id: str
    cursor: Union[None, Unset, str] = UNSET
    page_size: Union[Unset, int] = 25
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        api_key = self.api_key

        entity_type = self.entity_type.value

        search_id = self.search_id

        cursor: Union[None, Unset, str]
        if isinstance(self.cursor, Unset):
            cursor = UNSET
        else:
            cursor = self.cursor

        page_size = self.page_size


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
            "entityType": entity_type,
            "searchId": search_id,
        })
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if page_size is not UNSET:
            field_dict["pageSize"] = page_size

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        entity_type = PollCombinedSearchBodyEntityType(d.pop("entityType"))




        search_id = d.pop("searchId")

        def _parse_cursor(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cursor = _parse_cursor(d.pop("cursor", UNSET))


        page_size = d.pop("pageSize", UNSET)

        poll_combined_search_body = cls(
            api_key=api_key,
            entity_type=entity_type,
            search_id=search_id,
            cursor=cursor,
            page_size=page_size,
        )


        poll_combined_search_body.additional_properties = d
        return poll_combined_search_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.text_to_combined_search_response_200_output_data import TextToCombinedSearchResponse200OutputData
  from ..models.text_to_combined_search_response_200_output_profile_search_params_type_0 import TextToCombinedSearchResponse200OutputProfileSearchParamsType0
  from ..models.text_to_combined_search_response_200_output_company_search_params_type_0 import TextToCombinedSearchResponse200OutputCompanySearchParamsType0





T = TypeVar("T", bound="TextToCombinedSearchResponse200Output")



@_attrs_define
class TextToCombinedSearchResponse200Output:
    """ 
        Attributes:
            data (TextToCombinedSearchResponse200OutputData):
            company_search_params (Union['TextToCombinedSearchResponse200OutputCompanySearchParamsType0', None]):
            profile_search_params (Union['TextToCombinedSearchResponse200OutputProfileSearchParamsType0', None]):
     """

    data: 'TextToCombinedSearchResponse200OutputData'
    company_search_params: Union['TextToCombinedSearchResponse200OutputCompanySearchParamsType0', None]
    profile_search_params: Union['TextToCombinedSearchResponse200OutputProfileSearchParamsType0', None]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_combined_search_response_200_output_data import TextToCombinedSearchResponse200OutputData
        from ..models.text_to_combined_search_response_200_output_profile_search_params_type_0 import TextToCombinedSearchResponse200OutputProfileSearchParamsType0
        from ..models.text_to_combined_search_response_200_output_company_search_params_type_0 import TextToCombinedSearchResponse200OutputCompanySearchParamsType0
        data = self.data.to_dict()

        company_search_params: Union[None, dict[str, Any]]
        if isinstance(self.company_search_params, TextToCombinedSearchResponse200OutputCompanySearchParamsType0):
            company_search_params = self.company_search_params.to_dict()
        else:
            company_search_params = self.company_search_params

        profile_search_params: Union[None, dict[str, Any]]
        if isinstance(self.profile_search_params, TextToCombinedSearchResponse200OutputProfileSearchParamsType0):
            profile_search_params = self.profile_search_params.to_dict()
        else:
            profile_search_params = self.profile_search_params


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "data": data,
            "companySearchParams": company_search_params,
            "profileSearchParams": profile_search_params,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_combined_search_response_200_output_data import TextToCombinedSearchResponse200OutputData
        from ..models.text_to_combined_search_response_200_output_profile_search_params_type_0 import TextToCombinedSearchResponse200OutputProfileSearchParamsType0
        from ..models.text_to_combined_search_response_200_output_company_search_params_type_0 import TextToCombinedSearchResponse200OutputCompanySearchParamsType0
        d = dict(src_dict)
        data = TextToCombinedSearchResponse200OutputData.from_dict(d.pop("data"))




        def _parse_company_search_params(data: object) -> Union['TextToCombinedSearchResponse200OutputCompanySearchParamsType0', None]:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                company_search_params_type_0 = TextToCombinedSearchResponse200OutputCompanySearchParamsType0.from_dict(data)



                return company_search_params_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputCompanySearchParamsType0', None], data)

        company_search_params = _parse_company_search_params(d.pop("companySearchParams"))


        def _parse_profile_search_params(data: object) -> Union['TextToCombinedSearchResponse200OutputProfileSearchParamsType0', None]:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                profile_search_params_type_0 = TextToCombinedSearchResponse200OutputProfileSearchParamsType0.from_dict(data)



                return profile_search_params_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputProfileSearchParamsType0', None], data)

        profile_search_params = _parse_profile_search_params(d.pop("profileSearchParams"))


        text_to_combined_search_response_200_output = cls(
            data=data,
            company_search_params=company_search_params,
            profile_search_params=profile_search_params,
        )


        text_to_combined_search_response_200_output.additional_properties = d
        return text_to_combined_search_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import Union






T = TypeVar("T", bound="GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyAcceleratorsType0ItemFoundersType0Item")



@_attrs_define
class GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyAcceleratorsType0ItemFoundersType0Item:
    """ 
        Attributes:
            full_name (Union[Unset, str]):
            bio (Union[Unset, str]):
            job_title (Union[Unset, str]):
            is_active (Union[Unset, bool]):
            email_address (Union[Unset, str]):
            facebook_url (Union[Unset, str]):
            twitter_handle (Union[Unset, str]):
            linkedin_slug (Union[Unset, str]):
            github_username (Union[Unset, str]):
     """

    full_name: Union[Unset, str] = UNSET
    bio: Union[Unset, str] = UNSET
    job_title: Union[Unset, str] = UNSET
    is_active: Union[Unset, bool] = UNSET
    email_address: Union[Unset, str] = UNSET
    facebook_url: Union[Unset, str] = UNSET
    twitter_handle: Union[Unset, str] = UNSET
    linkedin_slug: Union[Unset, str] = UNSET
    github_username: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        full_name = self.full_name

        bio = self.bio

        job_title = self.job_title

        is_active = self.is_active

        email_address = self.email_address

        facebook_url = self.facebook_url

        twitter_handle = self.twitter_handle

        linkedin_slug = self.linkedin_slug

        github_username = self.github_username


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if full_name is not UNSET:
            field_dict["full_name"] = full_name
        if bio is not UNSET:
            field_dict["bio"] = bio
        if job_title is not UNSET:
            field_dict["job_title"] = job_title
        if is_active is not UNSET:
            field_dict["is_active"] = is_active
        if email_address is not UNSET:
            field_dict["email_address"] = email_address
        if facebook_url is not UNSET:
            field_dict["facebook_url"] = facebook_url
        if twitter_handle is not UNSET:
            field_dict["twitter_handle"] = twitter_handle
        if linkedin_slug is not UNSET:
            field_dict["linkedin_slug"] = linkedin_slug
        if github_username is not UNSET:
            field_dict["github_username"] = github_username

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        full_name = d.pop("full_name", UNSET)

        bio = d.pop("bio", UNSET)

        job_title = d.pop("job_title", UNSET)

        is_active = d.pop("is_active", UNSET)

        email_address = d.pop("email_address", UNSET)

        facebook_url = d.pop("facebook_url", UNSET)

        twitter_handle = d.pop("twitter_handle", UNSET)

        linkedin_slug = d.pop("linkedin_slug", UNSET)

        github_username = d.pop("github_username", UNSET)

        get_saved_search_run_companies_response_200_output_companies_item_company_accelerators_type_0_item_founders_type_0_item = cls(
            full_name=full_name,
            bio=bio,
            job_title=job_title,
            is_active=is_active,
            email_address=email_address,
            facebook_url=facebook_url,
            twitter_handle=twitter_handle,
            linkedin_slug=linkedin_slug,
            github_username=github_username,
        )


        get_saved_search_run_companies_response_200_output_companies_item_company_accelerators_type_0_item_founders_type_0_item.additional_properties = d
        return get_saved_search_run_companies_response_200_output_companies_item_company_accelerators_type_0_item_founders_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_combined_search_body_company_params_job_posting_stats_type_0_all_of_type_0_item_type_2_range_type_0_type import SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Type
from typing import cast

if TYPE_CHECKING:
  from ..models.sync_combined_search_body_company_params_job_posting_stats_type_0_all_of_type_0_item_type_2_range_type_0_range import SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Range





T = TypeVar("T", bound="SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0")



@_attrs_define
class SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0:
    """ 
        Attributes:
            type_ (SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Type):
            range_ (SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Range):
     """

    type_: SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Type
    range_: 'SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Range'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_body_company_params_job_posting_stats_type_0_all_of_type_0_item_type_2_range_type_0_range import SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Range
        type_ = self.type_.value

        range_ = self.range_.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "range": range_,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_body_company_params_job_posting_stats_type_0_all_of_type_0_item_type_2_range_type_0_range import SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Range
        d = dict(src_dict)
        type_ = SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Type(d.pop("type"))




        range_ = SyncCombinedSearchBodyCompanyParamsJobPostingStatsType0AllOfType0ItemType2RangeType0Range.from_dict(d.pop("range"))




        sync_combined_search_body_company_params_job_posting_stats_type_0_all_of_type_0_item_type_2_range_type_0 = cls(
            type_=type_,
            range_=range_,
        )


        sync_combined_search_body_company_params_job_posting_stats_type_0_all_of_type_0_item_type_2_range_type_0.additional_properties = d
        return sync_combined_search_body_company_params_job_posting_stats_type_0_all_of_type_0_item_type_2_range_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class PeopleSearchBodySearchParamsStealthV2Type0Status(str, Enum):
    CURRENTLY_IN_STEALTH = "currently-in-stealth"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_tags_response_200_output_company_tags_item import GetTagsResponse200OutputCompanyTagsItem
  from ..models.get_tags_response_200_output_profile_tags_item import GetTagsResponse200OutputProfileTagsItem





T = TypeVar("T", bound="GetTagsResponse200Output")



@_attrs_define
class GetTagsResponse200Output:
    """ 
        Attributes:
            profile_tags (list['GetTagsResponse200OutputProfileTagsItem']): List of all available profile tags
            company_tags (list['GetTagsResponse200OutputCompanyTagsItem']): List of all available company tags
     """

    profile_tags: list['GetTagsResponse200OutputProfileTagsItem']
    company_tags: list['GetTagsResponse200OutputCompanyTagsItem']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_tags_response_200_output_company_tags_item import GetTagsResponse200OutputCompanyTagsItem
        from ..models.get_tags_response_200_output_profile_tags_item import GetTagsResponse200OutputProfileTagsItem
        profile_tags = []
        for profile_tags_item_data in self.profile_tags:
            profile_tags_item = profile_tags_item_data.to_dict()
            profile_tags.append(profile_tags_item)



        company_tags = []
        for company_tags_item_data in self.company_tags:
            company_tags_item = company_tags_item_data.to_dict()
            company_tags.append(company_tags_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "profileTags": profile_tags,
            "companyTags": company_tags,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_tags_response_200_output_company_tags_item import GetTagsResponse200OutputCompanyTagsItem
        from ..models.get_tags_response_200_output_profile_tags_item import GetTagsResponse200OutputProfileTagsItem
        d = dict(src_dict)
        profile_tags = []
        _profile_tags = d.pop("profileTags")
        for profile_tags_item_data in (_profile_tags):
            profile_tags_item = GetTagsResponse200OutputProfileTagsItem.from_dict(profile_tags_item_data)



            profile_tags.append(profile_tags_item)


        company_tags = []
        _company_tags = d.pop("companyTags")
        for company_tags_item_data in (_company_tags):
            company_tags_item = GetTagsResponse200OutputCompanyTagsItem.from_dict(company_tags_item_data)



            company_tags.append(company_tags_item)


        get_tags_response_200_output = cls(
            profile_tags=profile_tags,
            company_tags=company_tags,
        )


        get_tags_response_200_output.additional_properties = d
        return get_tags_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.investment_search_response_200_output_investments_item_investor_type_type_1 import InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType1
from ..models.investment_search_response_200_output_investments_item_investor_type_type_2_type_1 import InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType2Type1
from ..models.investment_search_response_200_output_investments_item_investor_type_type_3_type_1 import InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType3Type1
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="InvestmentSearchResponse200OutputInvestmentsItemInvestor")



@_attrs_define
class InvestmentSearchResponse200OutputInvestmentsItemInvestor:
    """ Investor information

        Attributes:
            is_lead_investor (bool): Whether the investor was a lead investor
            name (Union[None, Unset, str]): Investor name
            type_ (Union[InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType1,
                InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType2Type1,
                InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType3Type1, None, Unset]): Investor type: 'person'
                or 'organization'
            linkedin_url (Union[None, Unset, str]): Full LinkedIn URL for the investor. Examples:
                'https://www.linkedin.com/in/johndoe/' for person or 'https://www.linkedin.com/company/sequoia-capital/' for
                organization. You can also use organization ID (e.g., 'https://www.linkedin.com/company/123456789/')
     """

    is_lead_investor: bool
    name: Union[None, Unset, str] = UNSET
    type_: Union[InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType1, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType2Type1, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType3Type1, None, Unset] = UNSET
    linkedin_url: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        is_lead_investor = self.is_lead_investor

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        type_: Union[None, Unset, str]
        if isinstance(self.type_, Unset):
            type_ = UNSET
        elif isinstance(self.type_, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType1):
            type_ = self.type_.value
        elif isinstance(self.type_, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType2Type1):
            type_ = self.type_.value
        elif isinstance(self.type_, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType3Type1):
            type_ = self.type_.value
        else:
            type_ = self.type_

        linkedin_url: Union[None, Unset, str]
        if isinstance(self.linkedin_url, Unset):
            linkedin_url = UNSET
        else:
            linkedin_url = self.linkedin_url


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "isLeadInvestor": is_lead_investor,
        })
        if name is not UNSET:
            field_dict["name"] = name
        if type_ is not UNSET:
            field_dict["type"] = type_
        if linkedin_url is not UNSET:
            field_dict["linkedinUrl"] = linkedin_url

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        is_lead_investor = d.pop("isLeadInvestor")

        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))


        def _parse_type_(data: object) -> Union[InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType1, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType2Type1, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                type_type_1 = InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType1(data)



                return type_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                type_type_2_type_1 = InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType2Type1(data)



                return type_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                type_type_3_type_1 = InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType3Type1(data)



                return type_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType1, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType2Type1, InvestmentSearchResponse200OutputInvestmentsItemInvestorTypeType3Type1, None, Unset], data)

        type_ = _parse_type_(d.pop("type", UNSET))


        def _parse_linkedin_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_url = _parse_linkedin_url(d.pop("linkedinUrl", UNSET))


        investment_search_response_200_output_investments_item_investor = cls(
            is_lead_investor=is_lead_investor,
            name=name,
            type_=type_,
            linkedin_url=linkedin_url,
        )


        investment_search_response_200_output_investments_item_investor.additional_properties = d
        return investment_search_response_200_output_investments_item_investor

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.people_search_count_body_search_params_past_jobs_type_0_any_of_type_0_item_company_type_0 import PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0





T = TypeVar("T", bound="PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0Item")



@_attrs_define
class PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0Item:
    """ 
        Attributes:
            job_title (Union[None, Unset, list[str]]):
            company (Union['PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0', None, Unset]):
     """

    job_title: Union[None, Unset, list[str]] = UNSET
    company: Union['PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.people_search_count_body_search_params_past_jobs_type_0_any_of_type_0_item_company_type_0 import PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0
        job_title: Union[None, Unset, list[str]]
        if isinstance(self.job_title, Unset):
            job_title = UNSET
        elif isinstance(self.job_title, list):
            job_title = self.job_title


        else:
            job_title = self.job_title

        company: Union[None, Unset, dict[str, Any]]
        if isinstance(self.company, Unset):
            company = UNSET
        elif isinstance(self.company, PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0):
            company = self.company.to_dict()
        else:
            company = self.company


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if job_title is not UNSET:
            field_dict["jobTitle"] = job_title
        if company is not UNSET:
            field_dict["company"] = company

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.people_search_count_body_search_params_past_jobs_type_0_any_of_type_0_item_company_type_0 import PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0
        d = dict(src_dict)
        def _parse_job_title(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                job_title_type_0 = cast(list[str], data)

                return job_title_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        job_title = _parse_job_title(d.pop("jobTitle", UNSET))


        def _parse_company(data: object) -> Union['PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                company_type_0 = PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0.from_dict(data)



                return company_type_0
            except: # noqa: E722
                pass
            return cast(Union['PeopleSearchCountBodySearchParamsPastJobsType0AnyOfType0ItemCompanyType0', None, Unset], data)

        company = _parse_company(d.pop("company", UNSET))


        people_search_count_body_search_params_past_jobs_type_0_any_of_type_0_item = cls(
            job_title=job_title,
            company=company,
        )


        people_search_count_body_search_params_past_jobs_type_0_any_of_type_0_item.additional_properties = d
        return people_search_count_body_search_params_past_jobs_type_0_any_of_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.text_to_profile_search_params_response_200_output_search_params_started_in_role_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_started_at_company_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_location_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_years_of_experience_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_education_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_languages_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1
  from ..models.text_to_profile_search_params_response_200_output_search_params_num_followers_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_tags_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_keyword_search_options_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_stealth_v2_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0
  from ..models.text_to_profile_search_params_response_200_output_search_params_time_zone_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_started_at_company_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1
  from ..models.text_to_profile_search_params_response_200_output_search_params_num_connections_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_fuzzy_name_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_stealth_v2_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1
  from ..models.text_to_profile_search_params_response_200_output_search_params_past_jobs_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_started_in_role_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1
  from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_2 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2
  from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_job_title_v3_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0
  from ..models.text_to_profile_search_params_response_200_output_search_params_keywords_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_country_3_letter_code_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0
  from ..models.text_to_profile_search_params_response_200_output_search_params_approx_age_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0





T = TypeVar("T", bound="TextToProfileSearchParamsResponse200OutputSearchParams")



@_attrs_define
class TextToProfileSearchParamsResponse200OutputSearchParams:
    """ 
        Attributes:
            job_title_v3 (Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0', None, Unset]):
            job_status (Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0',
                'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1',
                'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2', None, Unset]):
            approx_age (Union['TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0', None, Unset]):
            started_in_role (Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0',
                'TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1', None, Unset]):
            started_at_company (Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0',
                'TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1', None, Unset]):
            years_of_experience (Union['TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0', None,
                Unset]):
            keywords (Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset]):
            keyword_search_options (Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0',
                None, Unset]):
            fuzzy_name (Union['TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0', None, Unset]):
            tags (Union['TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0', None, Unset]):
            stealth_v2 (Union['TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0',
                'TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1', None, Unset]):
            country_3_letter_code (Union['TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0',
                None, Unset]):
            location (Union['TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0', None, Unset]):
            time_zone (Union['TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0', None, Unset]):
            education (Union['TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0', None, Unset]):
            languages (Union['TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0', None, Unset]):
            past_jobs (Union['TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0', None, Unset]):
            num_connections (Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0', None,
                Unset]):
            num_followers (Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0', None, Unset]):
            max_people_per_company (Union[None, Unset, float]):
     """

    job_title_v3: Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0', None, Unset] = UNSET
    job_status: Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1', 'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2', None, Unset] = UNSET
    approx_age: Union['TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0', None, Unset] = UNSET
    started_in_role: Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1', None, Unset] = UNSET
    started_at_company: Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1', None, Unset] = UNSET
    years_of_experience: Union['TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0', None, Unset] = UNSET
    keywords: Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset] = UNSET
    keyword_search_options: Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0', None, Unset] = UNSET
    fuzzy_name: Union['TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0', None, Unset] = UNSET
    tags: Union['TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0', None, Unset] = UNSET
    stealth_v2: Union['TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1', None, Unset] = UNSET
    country_3_letter_code: Union['TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0', None, Unset] = UNSET
    location: Union['TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0', None, Unset] = UNSET
    time_zone: Union['TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0', None, Unset] = UNSET
    education: Union['TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0', None, Unset] = UNSET
    languages: Union['TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0', None, Unset] = UNSET
    past_jobs: Union['TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0', None, Unset] = UNSET
    num_connections: Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0', None, Unset] = UNSET
    num_followers: Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0', None, Unset] = UNSET
    max_people_per_company: Union[None, Unset, float] = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_in_role_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_at_company_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_location_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_years_of_experience_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_education_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_languages_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1
        from ..models.text_to_profile_search_params_response_200_output_search_params_num_followers_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_tags_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_keyword_search_options_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_stealth_v2_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0
        from ..models.text_to_profile_search_params_response_200_output_search_params_time_zone_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_at_company_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1
        from ..models.text_to_profile_search_params_response_200_output_search_params_num_connections_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_fuzzy_name_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_stealth_v2_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1
        from ..models.text_to_profile_search_params_response_200_output_search_params_past_jobs_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_in_role_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_2 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_title_v3_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0
        from ..models.text_to_profile_search_params_response_200_output_search_params_keywords_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_country_3_letter_code_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_approx_age_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0
        job_title_v3: Union[None, Unset, dict[str, Any]]
        if isinstance(self.job_title_v3, Unset):
            job_title_v3 = UNSET
        elif isinstance(self.job_title_v3, TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0):
            job_title_v3 = self.job_title_v3.to_dict()
        else:
            job_title_v3 = self.job_title_v3

        job_status: Union[None, Unset, dict[str, Any]]
        if isinstance(self.job_status, Unset):
            job_status = UNSET
        elif isinstance(self.job_status, TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0):
            job_status = self.job_status.to_dict()
        elif isinstance(self.job_status, TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1):
            job_status = self.job_status.to_dict()
        elif isinstance(self.job_status, TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2):
            job_status = self.job_status.to_dict()
        else:
            job_status = self.job_status

        approx_age: Union[None, Unset, dict[str, Any]]
        if isinstance(self.approx_age, Unset):
            approx_age = UNSET
        elif isinstance(self.approx_age, TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0):
            approx_age = self.approx_age.to_dict()
        else:
            approx_age = self.approx_age

        started_in_role: Union[None, Unset, dict[str, Any]]
        if isinstance(self.started_in_role, Unset):
            started_in_role = UNSET
        elif isinstance(self.started_in_role, TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0):
            started_in_role = self.started_in_role.to_dict()
        elif isinstance(self.started_in_role, TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1):
            started_in_role = self.started_in_role.to_dict()
        else:
            started_in_role = self.started_in_role

        started_at_company: Union[None, Unset, dict[str, Any]]
        if isinstance(self.started_at_company, Unset):
            started_at_company = UNSET
        elif isinstance(self.started_at_company, TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0):
            started_at_company = self.started_at_company.to_dict()
        elif isinstance(self.started_at_company, TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1):
            started_at_company = self.started_at_company.to_dict()
        else:
            started_at_company = self.started_at_company

        years_of_experience: Union[None, Unset, dict[str, Any]]
        if isinstance(self.years_of_experience, Unset):
            years_of_experience = UNSET
        elif isinstance(self.years_of_experience, TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0):
            years_of_experience = self.years_of_experience.to_dict()
        else:
            years_of_experience = self.years_of_experience

        keywords: Union[None, Unset, dict[str, Any]]
        if isinstance(self.keywords, Unset):
            keywords = UNSET
        elif isinstance(self.keywords, TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0):
            keywords = self.keywords.to_dict()
        else:
            keywords = self.keywords

        keyword_search_options: Union[None, Unset, dict[str, Any]]
        if isinstance(self.keyword_search_options, Unset):
            keyword_search_options = UNSET
        elif isinstance(self.keyword_search_options, TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0):
            keyword_search_options = self.keyword_search_options.to_dict()
        else:
            keyword_search_options = self.keyword_search_options

        fuzzy_name: Union[None, Unset, dict[str, Any]]
        if isinstance(self.fuzzy_name, Unset):
            fuzzy_name = UNSET
        elif isinstance(self.fuzzy_name, TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0):
            fuzzy_name = self.fuzzy_name.to_dict()
        else:
            fuzzy_name = self.fuzzy_name

        tags: Union[None, Unset, dict[str, Any]]
        if isinstance(self.tags, Unset):
            tags = UNSET
        elif isinstance(self.tags, TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0):
            tags = self.tags.to_dict()
        else:
            tags = self.tags

        stealth_v2: Union[None, Unset, dict[str, Any]]
        if isinstance(self.stealth_v2, Unset):
            stealth_v2 = UNSET
        elif isinstance(self.stealth_v2, TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0):
            stealth_v2 = self.stealth_v2.to_dict()
        elif isinstance(self.stealth_v2, TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1):
            stealth_v2 = self.stealth_v2.to_dict()
        else:
            stealth_v2 = self.stealth_v2

        country_3_letter_code: Union[None, Unset, dict[str, Any]]
        if isinstance(self.country_3_letter_code, Unset):
            country_3_letter_code = UNSET
        elif isinstance(self.country_3_letter_code, TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0):
            country_3_letter_code = self.country_3_letter_code.to_dict()
        else:
            country_3_letter_code = self.country_3_letter_code

        location: Union[None, Unset, dict[str, Any]]
        if isinstance(self.location, Unset):
            location = UNSET
        elif isinstance(self.location, TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0):
            location = self.location.to_dict()
        else:
            location = self.location

        time_zone: Union[None, Unset, dict[str, Any]]
        if isinstance(self.time_zone, Unset):
            time_zone = UNSET
        elif isinstance(self.time_zone, TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0):
            time_zone = self.time_zone.to_dict()
        else:
            time_zone = self.time_zone

        education: Union[None, Unset, dict[str, Any]]
        if isinstance(self.education, Unset):
            education = UNSET
        elif isinstance(self.education, TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0):
            education = self.education.to_dict()
        else:
            education = self.education

        languages: Union[None, Unset, dict[str, Any]]
        if isinstance(self.languages, Unset):
            languages = UNSET
        elif isinstance(self.languages, TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0):
            languages = self.languages.to_dict()
        else:
            languages = self.languages

        past_jobs: Union[None, Unset, dict[str, Any]]
        if isinstance(self.past_jobs, Unset):
            past_jobs = UNSET
        elif isinstance(self.past_jobs, TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0):
            past_jobs = self.past_jobs.to_dict()
        else:
            past_jobs = self.past_jobs

        num_connections: Union[None, Unset, dict[str, Any]]
        if isinstance(self.num_connections, Unset):
            num_connections = UNSET
        elif isinstance(self.num_connections, TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0):
            num_connections = self.num_connections.to_dict()
        else:
            num_connections = self.num_connections

        num_followers: Union[None, Unset, dict[str, Any]]
        if isinstance(self.num_followers, Unset):
            num_followers = UNSET
        elif isinstance(self.num_followers, TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0):
            num_followers = self.num_followers.to_dict()
        else:
            num_followers = self.num_followers

        max_people_per_company: Union[None, Unset, float]
        if isinstance(self.max_people_per_company, Unset):
            max_people_per_company = UNSET
        else:
            max_people_per_company = self.max_people_per_company


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if job_title_v3 is not UNSET:
            field_dict["jobTitleV3"] = job_title_v3
        if job_status is not UNSET:
            field_dict["jobStatus"] = job_status
        if approx_age is not UNSET:
            field_dict["approxAge"] = approx_age
        if started_in_role is not UNSET:
            field_dict["startedInRole"] = started_in_role
        if started_at_company is not UNSET:
            field_dict["startedAtCompany"] = started_at_company
        if years_of_experience is not UNSET:
            field_dict["yearsOfExperience"] = years_of_experience
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if keyword_search_options is not UNSET:
            field_dict["keywordSearchOptions"] = keyword_search_options
        if fuzzy_name is not UNSET:
            field_dict["fuzzyName"] = fuzzy_name
        if tags is not UNSET:
            field_dict["tags"] = tags
        if stealth_v2 is not UNSET:
            field_dict["stealthV2"] = stealth_v2
        if country_3_letter_code is not UNSET:
            field_dict["country3LetterCode"] = country_3_letter_code
        if location is not UNSET:
            field_dict["location"] = location
        if time_zone is not UNSET:
            field_dict["timeZone"] = time_zone
        if education is not UNSET:
            field_dict["education"] = education
        if languages is not UNSET:
            field_dict["languages"] = languages
        if past_jobs is not UNSET:
            field_dict["pastJobs"] = past_jobs
        if num_connections is not UNSET:
            field_dict["numConnections"] = num_connections
        if num_followers is not UNSET:
            field_dict["numFollowers"] = num_followers
        if max_people_per_company is not UNSET:
            field_dict["maxPeoplePerCompany"] = max_people_per_company

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_in_role_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_at_company_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_location_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_years_of_experience_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_education_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_languages_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1
        from ..models.text_to_profile_search_params_response_200_output_search_params_num_followers_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_tags_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_keyword_search_options_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_stealth_v2_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0
        from ..models.text_to_profile_search_params_response_200_output_search_params_time_zone_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_at_company_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1
        from ..models.text_to_profile_search_params_response_200_output_search_params_num_connections_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_fuzzy_name_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_stealth_v2_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1
        from ..models.text_to_profile_search_params_response_200_output_search_params_past_jobs_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_started_in_role_type_1 import TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_2 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_status_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_job_title_v3_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0
        from ..models.text_to_profile_search_params_response_200_output_search_params_keywords_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_country_3_letter_code_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0
        from ..models.text_to_profile_search_params_response_200_output_search_params_approx_age_type_0 import TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0
        d = dict(src_dict)
        def _parse_job_title_v3(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_title_v3_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0.from_dict(data)



                return job_title_v3_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobTitleV3Type0', None, Unset], data)

        job_title_v3 = _parse_job_title_v3(d.pop("jobTitleV3", UNSET))


        def _parse_job_status(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1', 'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_status_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0.from_dict(data)



                return job_status_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_status_type_1 = TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1.from_dict(data)



                return job_status_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                job_status_type_2 = TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2.from_dict(data)



                return job_status_type_2
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType1', 'TextToProfileSearchParamsResponse200OutputSearchParamsJobStatusType2', None, Unset], data)

        job_status = _parse_job_status(d.pop("jobStatus", UNSET))


        def _parse_approx_age(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                approx_age_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0.from_dict(data)



                return approx_age_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsApproxAgeType0', None, Unset], data)

        approx_age = _parse_approx_age(d.pop("approxAge", UNSET))


        def _parse_started_in_role(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                started_in_role_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0.from_dict(data)



                return started_in_role_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                started_in_role_type_1 = TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1.from_dict(data)



                return started_in_role_type_1
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStartedInRoleType1', None, Unset], data)

        started_in_role = _parse_started_in_role(d.pop("startedInRole", UNSET))


        def _parse_started_at_company(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                started_at_company_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0.from_dict(data)



                return started_at_company_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                started_at_company_type_1 = TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1.from_dict(data)



                return started_at_company_type_1
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStartedAtCompanyType1', None, Unset], data)

        started_at_company = _parse_started_at_company(d.pop("startedAtCompany", UNSET))


        def _parse_years_of_experience(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                years_of_experience_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0.from_dict(data)



                return years_of_experience_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsYearsOfExperienceType0', None, Unset], data)

        years_of_experience = _parse_years_of_experience(d.pop("yearsOfExperience", UNSET))


        def _parse_keywords(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                keywords_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0.from_dict(data)



                return keywords_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordsType0', None, Unset], data)

        keywords = _parse_keywords(d.pop("keywords", UNSET))


        def _parse_keyword_search_options(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                keyword_search_options_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0.from_dict(data)



                return keyword_search_options_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsKeywordSearchOptionsType0', None, Unset], data)

        keyword_search_options = _parse_keyword_search_options(d.pop("keywordSearchOptions", UNSET))


        def _parse_fuzzy_name(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                fuzzy_name_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0.from_dict(data)



                return fuzzy_name_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsFuzzyNameType0', None, Unset], data)

        fuzzy_name = _parse_fuzzy_name(d.pop("fuzzyName", UNSET))


        def _parse_tags(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                tags_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0.from_dict(data)



                return tags_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsTagsType0', None, Unset], data)

        tags = _parse_tags(d.pop("tags", UNSET))


        def _parse_stealth_v2(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                stealth_v2_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0.from_dict(data)



                return stealth_v2_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                stealth_v2_type_1 = TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1.from_dict(data)



                return stealth_v2_type_1
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type0', 'TextToProfileSearchParamsResponse200OutputSearchParamsStealthV2Type1', None, Unset], data)

        stealth_v2 = _parse_stealth_v2(d.pop("stealthV2", UNSET))


        def _parse_country_3_letter_code(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                country_3_letter_code_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0.from_dict(data)



                return country_3_letter_code_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsCountry3LetterCodeType0', None, Unset], data)

        country_3_letter_code = _parse_country_3_letter_code(d.pop("country3LetterCode", UNSET))


        def _parse_location(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                location_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0.from_dict(data)



                return location_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0', None, Unset], data)

        location = _parse_location(d.pop("location", UNSET))


        def _parse_time_zone(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                time_zone_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0.from_dict(data)



                return time_zone_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsTimeZoneType0', None, Unset], data)

        time_zone = _parse_time_zone(d.pop("timeZone", UNSET))


        def _parse_education(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                education_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0.from_dict(data)



                return education_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsEducationType0', None, Unset], data)

        education = _parse_education(d.pop("education", UNSET))


        def _parse_languages(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                languages_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0.from_dict(data)



                return languages_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsLanguagesType0', None, Unset], data)

        languages = _parse_languages(d.pop("languages", UNSET))


        def _parse_past_jobs(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                past_jobs_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0.from_dict(data)



                return past_jobs_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsPastJobsType0', None, Unset], data)

        past_jobs = _parse_past_jobs(d.pop("pastJobs", UNSET))


        def _parse_num_connections(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                num_connections_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0.from_dict(data)



                return num_connections_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumConnectionsType0', None, Unset], data)

        num_connections = _parse_num_connections(d.pop("numConnections", UNSET))


        def _parse_num_followers(data: object) -> Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                num_followers_type_0 = TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0.from_dict(data)



                return num_followers_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToProfileSearchParamsResponse200OutputSearchParamsNumFollowersType0', None, Unset], data)

        num_followers = _parse_num_followers(d.pop("numFollowers", UNSET))


        def _parse_max_people_per_company(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        max_people_per_company = _parse_max_people_per_company(d.pop("maxPeoplePerCompany", UNSET))


        text_to_profile_search_params_response_200_output_search_params = cls(
            job_title_v3=job_title_v3,
            job_status=job_status,
            approx_age=approx_age,
            started_in_role=started_in_role,
            started_at_company=started_at_company,
            years_of_experience=years_of_experience,
            keywords=keywords,
            keyword_search_options=keyword_search_options,
            fuzzy_name=fuzzy_name,
            tags=tags,
            stealth_v2=stealth_v2,
            country_3_letter_code=country_3_letter_code,
            location=location,
            time_zone=time_zone,
            education=education,
            languages=languages,
            past_jobs=past_jobs,
            num_connections=num_connections,
            num_followers=num_followers,
            max_people_per_company=max_people_per_company,
        )

        return text_to_profile_search_params_response_200_output_search_params




from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.people_search_body_search_params_fuzzy_name_type_0_any_of_item import PeopleSearchBodySearchParamsFuzzyNameType0AnyOfItem





T = TypeVar("T", bound="PeopleSearchBodySearchParamsFuzzyNameType0")



@_attrs_define
class PeopleSearchBodySearchParamsFuzzyNameType0:
    """ 
        Attributes:
            any_of (list['PeopleSearchBodySearchParamsFuzzyNameType0AnyOfItem']):
     """

    any_of: list['PeopleSearchBodySearchParamsFuzzyNameType0AnyOfItem']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.people_search_body_search_params_fuzzy_name_type_0_any_of_item import PeopleSearchBodySearchParamsFuzzyNameType0AnyOfItem
        any_of = []
        for any_of_item_data in self.any_of:
            any_of_item = any_of_item_data.to_dict()
            any_of.append(any_of_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "anyOf": any_of,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.people_search_body_search_params_fuzzy_name_type_0_any_of_item import PeopleSearchBodySearchParamsFuzzyNameType0AnyOfItem
        d = dict(src_dict)
        any_of = []
        _any_of = d.pop("anyOf")
        for any_of_item_data in (_any_of):
            any_of_item = PeopleSearchBodySearchParamsFuzzyNameType0AnyOfItem.from_dict(any_of_item_data)



            any_of.append(any_of_item)


        people_search_body_search_params_fuzzy_name_type_0 = cls(
            any_of=any_of,
        )


        people_search_body_search_params_fuzzy_name_type_0.additional_properties = d
        return people_search_body_search_params_fuzzy_name_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class TextToCompanySearchResponse200OutputSearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0Strategy(str, Enum):
    RADIAL_DISTANCE = "radial-distance"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="PollCombinedSearchResponse200OutputDataType1ItemsItemCoursesType0Item")



@_attrs_define
class PollCombinedSearchResponse200OutputDataType1ItemsItemCoursesType0Item:
    """ 
        Attributes:
            title (Union[None, Unset, str]):
            course_number (Union[None, Unset, str]):
            association (Union[Unset, None]):
     """

    title: Union[None, Unset, str] = UNSET
    course_number: Union[None, Unset, str] = UNSET
    association: Union[Unset, None] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        course_number: Union[None, Unset, str]
        if isinstance(self.course_number, Unset):
            course_number = UNSET
        else:
            course_number = self.course_number

        association = self.association


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if title is not UNSET:
            field_dict["title"] = title
        if course_number is not UNSET:
            field_dict["course_number"] = course_number
        if association is not UNSET:
            field_dict["association"] = association

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))


        def _parse_course_number(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        course_number = _parse_course_number(d.pop("course_number", UNSET))


        association = d.pop("association", UNSET)

        poll_combined_search_response_200_output_data_type_1_items_item_courses_type_0_item = cls(
            title=title,
            course_number=course_number,
            association=association,
        )


        poll_combined_search_response_200_output_data_type_1_items_item_courses_type_0_item.additional_properties = d
        return poll_combined_search_response_200_output_data_type_1_items_item_courses_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeesToMatchType1Tag(str, Enum):
    FINITERANGE = "finiteRange"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToCombinedSearchResponse200OutputCompanySearchParamsType0OfficeLocationsV2Type0AnyOfType0ItemType2Type(str, Enum):
    GEOGRAPHY = "geography"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CompanySearchBodySearchParamsAcceleratorsV2Type0AnyOfType0ItemBatchSelectionType0Strategy(str, Enum):
    ALL_BATCHES = "all-batches"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToCompanySearchResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType2LocationType0Center")



@_attrs_define
class TextToCompanySearchResponse200OutputSearchParamsOfficeLocationsV2Type0NoneOfType0ItemType2LocationType0Center:
    """ 
        Attributes:
            latitude (float):
            longitude (float):
            name (Union[None, Unset, str]):
            address (Union[None, Unset, str]):
     """

    latitude: float
    longitude: float
    name: Union[None, Unset, str] = UNSET
    address: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        latitude = self.latitude

        longitude = self.longitude

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        address: Union[None, Unset, str]
        if isinstance(self.address, Unset):
            address = UNSET
        else:
            address = self.address


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "latitude": latitude,
            "longitude": longitude,
        })
        if name is not UNSET:
            field_dict["name"] = name
        if address is not UNSET:
            field_dict["address"] = address

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        latitude = d.pop("latitude")

        longitude = d.pop("longitude")

        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))


        def _parse_address(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        address = _parse_address(d.pop("address", UNSET))


        text_to_company_search_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_2_location_type_0_center = cls(
            latitude=latitude,
            longitude=longitude,
            name=name,
            address=address,
        )


        text_to_company_search_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_2_location_type_0_center.additional_properties = d
        return text_to_company_search_response_200_output_search_params_office_locations_v2_type_0_none_of_type_0_item_type_2_location_type_0_center

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="PollGoogleMapsResultsResponse200OutputResultsItem")



@_attrs_define
class PollGoogleMapsResultsResponse200OutputResultsItem:
    """ 
        Attributes:
            place_id (str):
            name (str):
            latitude (float):
            longitude (float):
            all_types (list[str]):
            google_maps_url (str): The Google Maps URL of the place
            address (Union[None, Unset, str]):
            description (Union[None, Unset, str]):
            website (Union[None, Unset, str]):
            rating (Union[None, Unset, float]):
            num_reviews (Union[None, Unset, int]):
            primary_type (Union[None, Unset, str]):
            price_level (Union[None, Unset, str]):
            phone_number (Union[None, Unset, str]):
            country_iso_code (Union[None, Unset, str]):
     """

    place_id: str
    name: str
    latitude: float
    longitude: float
    all_types: list[str]
    google_maps_url: str
    address: Union[None, Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    website: Union[None, Unset, str] = UNSET
    rating: Union[None, Unset, float] = UNSET
    num_reviews: Union[None, Unset, int] = UNSET
    primary_type: Union[None, Unset, str] = UNSET
    price_level: Union[None, Unset, str] = UNSET
    phone_number: Union[None, Unset, str] = UNSET
    country_iso_code: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        place_id = self.place_id

        name = self.name

        latitude = self.latitude

        longitude = self.longitude

        all_types = self.all_types



        google_maps_url = self.google_maps_url

        address: Union[None, Unset, str]
        if isinstance(self.address, Unset):
            address = UNSET
        else:
            address = self.address

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        website: Union[None, Unset, str]
        if isinstance(self.website, Unset):
            website = UNSET
        else:
            website = self.website

        rating: Union[None, Unset, float]
        if isinstance(self.rating, Unset):
            rating = UNSET
        else:
            rating = self.rating

        num_reviews: Union[None, Unset, int]
        if isinstance(self.num_reviews, Unset):
            num_reviews = UNSET
        else:
            num_reviews = self.num_reviews

        primary_type: Union[None, Unset, str]
        if isinstance(self.primary_type, Unset):
            primary_type = UNSET
        else:
            primary_type = self.primary_type

        price_level: Union[None, Unset, str]
        if isinstance(self.price_level, Unset):
            price_level = UNSET
        else:
            price_level = self.price_level

        phone_number: Union[None, Unset, str]
        if isinstance(self.phone_number, Unset):
            phone_number = UNSET
        else:
            phone_number = self.phone_number

        country_iso_code: Union[None, Unset, str]
        if isinstance(self.country_iso_code, Unset):
            country_iso_code = UNSET
        else:
            country_iso_code = self.country_iso_code


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "placeId": place_id,
            "name": name,
            "latitude": latitude,
            "longitude": longitude,
            "allTypes": all_types,
            "googleMapsURL": google_maps_url,
        })
        if address is not UNSET:
            field_dict["address"] = address
        if description is not UNSET:
            field_dict["description"] = description
        if website is not UNSET:
            field_dict["website"] = website
        if rating is not UNSET:
            field_dict["rating"] = rating
        if num_reviews is not UNSET:
            field_dict["numReviews"] = num_reviews
        if primary_type is not UNSET:
            field_dict["primaryType"] = primary_type
        if price_level is not UNSET:
            field_dict["priceLevel"] = price_level
        if phone_number is not UNSET:
            field_dict["phoneNumber"] = phone_number
        if country_iso_code is not UNSET:
            field_dict["countryIsoCode"] = country_iso_code

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        place_id = d.pop("placeId")

        name = d.pop("name")

        latitude = d.pop("latitude")

        longitude = d.pop("longitude")

        all_types = cast(list[str], d.pop("allTypes"))


        google_maps_url = d.pop("googleMapsURL")

        def _parse_address(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        address = _parse_address(d.pop("address", UNSET))


        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))


        def _parse_website(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        website = _parse_website(d.pop("website", UNSET))


        def _parse_rating(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        rating = _parse_rating(d.pop("rating", UNSET))


        def _parse_num_reviews(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        num_reviews = _parse_num_reviews(d.pop("numReviews", UNSET))


        def _parse_primary_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        primary_type = _parse_primary_type(d.pop("primaryType", UNSET))


        def _parse_price_level(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        price_level = _parse_price_level(d.pop("priceLevel", UNSET))


        def _parse_phone_number(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        phone_number = _parse_phone_number(d.pop("phoneNumber", UNSET))


        def _parse_country_iso_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_iso_code = _parse_country_iso_code(d.pop("countryIsoCode", UNSET))


        poll_google_maps_results_response_200_output_results_item = cls(
            place_id=place_id,
            name=name,
            latitude=latitude,
            longitude=longitude,
            all_types=all_types,
            google_maps_url=google_maps_url,
            address=address,
            description=description,
            website=website,
            rating=rating,
            num_reviews=num_reviews,
            primary_type=primary_type,
            price_level=price_level,
            phone_number=phone_number,
            country_iso_code=country_iso_code,
        )


        poll_google_maps_results_response_200_output_results_item.additional_properties = d
        return poll_google_maps_results_response_200_output_results_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="KitchenSinkBulkProfileBodyProfilesItemCompanyDomainType0")



@_attrs_define
class KitchenSinkBulkProfileBodyProfilesItemCompanyDomainType0:
    """ 
        Attributes:
            value (Union[None, Unset, str]):
     """

    value: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        value: Union[None, Unset, str]
        if isinstance(self.value, Unset):
            value = UNSET
        else:
            value = self.value


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_value(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        value = _parse_value(d.pop("value", UNSET))


        kitchen_sink_bulk_profile_body_profiles_item_company_domain_type_0 = cls(
            value=value,
        )


        kitchen_sink_bulk_profile_body_profiles_item_company_domain_type_0.additional_properties = d
        return kitchen_sink_bulk_profile_body_profiles_item_company_domain_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_profile_search_response_200_output_search_params_job_title_v3_type_0_all_of_type_0_item_type_1_seniority_item import TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1SeniorityItem
from ..models.text_to_profile_search_response_200_output_search_params_job_title_v3_type_0_all_of_type_0_item_type_1_type import TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1Type
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1")



@_attrs_define
class TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1:
    """ 
        Attributes:
            type_ (TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1Type):
            seniority
                (list[TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1SeniorityItem]):
            keywords (Union[None, Unset, list[str]]):
     """

    type_: TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1Type
    seniority: list[TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1SeniorityItem]
    keywords: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_.value

        seniority = []
        for seniority_item_data in self.seniority:
            seniority_item = seniority_item_data.value
            seniority.append(seniority_item)



        keywords: Union[None, Unset, list[str]]
        if isinstance(self.keywords, Unset):
            keywords = UNSET
        elif isinstance(self.keywords, list):
            keywords = self.keywords


        else:
            keywords = self.keywords


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "seniority": seniority,
        })
        if keywords is not UNSET:
            field_dict["keywords"] = keywords

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1Type(d.pop("type"))




        seniority = []
        _seniority = d.pop("seniority")
        for seniority_item_data in (_seniority):
            seniority_item = TextToProfileSearchResponse200OutputSearchParamsJobTitleV3Type0AllOfType0ItemType1SeniorityItem(seniority_item_data)



            seniority.append(seniority_item)


        def _parse_keywords(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                keywords_type_0 = cast(list[str], data)

                return keywords_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        keywords = _parse_keywords(d.pop("keywords", UNSET))


        text_to_profile_search_response_200_output_search_params_job_title_v3_type_0_all_of_type_0_item_type_1 = cls(
            type_=type_,
            seniority=seniority,
            keywords=keywords,
        )


        text_to_profile_search_response_200_output_search_params_job_title_v3_type_0_all_of_type_0_item_type_1.additional_properties = d
        return text_to_profile_search_response_200_output_search_params_job_title_v3_type_0_all_of_type_0_item_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="GetProspectExclusionListsResponse200OutputItem")



@_attrs_define
class GetProspectExclusionListsResponse200OutputItem:
    """ 
        Attributes:
            list_id (str): Id of the prospect exclusion list
            name (str): Name of the prospect exclusion list
     """

    list_id: str
    name: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        list_id = self.list_id

        name = self.name


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "listId": list_id,
            "name": name,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        list_id = d.pop("listId")

        name = d.pop("name")

        get_prospect_exclusion_lists_response_200_output_item = cls(
            list_id=list_id,
            name=name,
        )


        get_prospect_exclusion_lists_response_200_output_item.additional_properties = d
        return get_prospect_exclusion_lists_response_200_output_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_combined_search_response_200_output_profile_search_params_type_0_job_title_v3_type_0_any_of_type_0_item_type_2_type import TextToCombinedSearchResponse200OutputProfileSearchParamsType0JobTitleV3Type0AnyOfType0ItemType2Type
from typing import cast






T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputProfileSearchParamsType0JobTitleV3Type0AnyOfType0ItemType2")



@_attrs_define
class TextToCombinedSearchResponse200OutputProfileSearchParamsType0JobTitleV3Type0AnyOfType0ItemType2:
    """ 
        Attributes:
            type_ (TextToCombinedSearchResponse200OutputProfileSearchParamsType0JobTitleV3Type0AnyOfType0ItemType2Type):
            keyword_arrays (list[list[str]]):
     """

    type_: TextToCombinedSearchResponse200OutputProfileSearchParamsType0JobTitleV3Type0AnyOfType0ItemType2Type
    keyword_arrays: list[list[str]]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_.value

        keyword_arrays = []
        for keyword_arrays_item_data in self.keyword_arrays:
            keyword_arrays_item = keyword_arrays_item_data


            keyword_arrays.append(keyword_arrays_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "keywordArrays": keyword_arrays,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = TextToCombinedSearchResponse200OutputProfileSearchParamsType0JobTitleV3Type0AnyOfType0ItemType2Type(d.pop("type"))




        keyword_arrays = []
        _keyword_arrays = d.pop("keywordArrays")
        for keyword_arrays_item_data in (_keyword_arrays):
            keyword_arrays_item = cast(list[str], keyword_arrays_item_data)

            keyword_arrays.append(keyword_arrays_item)


        text_to_combined_search_response_200_output_profile_search_params_type_0_job_title_v3_type_0_any_of_type_0_item_type_2 = cls(
            type_=type_,
            keyword_arrays=keyword_arrays,
        )


        text_to_combined_search_response_200_output_profile_search_params_type_0_job_title_v3_type_0_any_of_type_0_item_type_2.additional_properties = d
        return text_to_combined_search_response_200_output_profile_search_params_type_0_job_title_v3_type_0_any_of_type_0_item_type_2

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchBodyProfileParamsEducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Which(str, Enum):
    CURRENT = "current"
    PREVIOUS = "previous"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingsV2Type0AllOfType0ItemJobPostingStatusType1(str, Enum):
    ACTIVE = "active"
    CLOSED = "closed"
    EITHER = "either"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsAcceleratorsV2Type0AnyOfType0ItemAcceleratorName(str, Enum):
    A16Z_SPEEDRUN = "a16z_speedrun"
    ACCEL_ATOMS = "accel_atoms"
    AI2_INCUBATOR = "ai2_incubator"
    ALCHEMIST_ACCELERATOR = "alchemist_accelerator"
    ALLIANCE = "alliance"
    ANTLER = "antler"
    BERKELEY_SKYDECK = "berkeley_skydeck"
    FOUNDERS_INC = "founders_inc"
    GOOGLE_STARTUPS = "google_startups"
    LAUNCH_ACCELERATOR = "launch_accelerator"
    NEO = "neo"
    PEAR_X = "pear_x"
    PLUG_AND_PLAY = "plug_and_play"
    SOSV = "sosv"
    SOUTH_PARK_COMMONS = "south_park_commons"
    STARTX = "startx"
    TECHSTARS = "techstars"
    THE_MINT = "the_mint"
    YCOMBINATOR = "ycombinator"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class PeopleSearchCountBodySearchParamsTimeZoneType0AnyOfItemStrategyType0Mode(str, Enum):
    MIDPOINT_WITH_BUFFER = "midpoint-with-buffer"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToCompanySearchParamsResponse200OutputSearchParamsJobPostingsV2Type0NoneOfType0ItemJobLocationTypeType0Item(str, Enum):
    HYBRID = "Hybrid"
    ON_SITE = "On-site"
    REMOTE = "Remote"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.investment_search_response_200_output_investments_item import InvestmentSearchResponse200OutputInvestmentsItem





T = TypeVar("T", bound="InvestmentSearchResponse200Output")



@_attrs_define
class InvestmentSearchResponse200Output:
    """ 
        Attributes:
            investments (list['InvestmentSearchResponse200OutputInvestmentsItem']): Array of investment results
            next_cursor (Union[None, str]): Pagination cursor for the next page. Null if there are no more results.
     """

    investments: list['InvestmentSearchResponse200OutputInvestmentsItem']
    next_cursor: Union[None, str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.investment_search_response_200_output_investments_item import InvestmentSearchResponse200OutputInvestmentsItem
        investments = []
        for investments_item_data in self.investments:
            investments_item = investments_item_data.to_dict()
            investments.append(investments_item)



        next_cursor: Union[None, str]
        next_cursor = self.next_cursor


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "investments": investments,
            "nextCursor": next_cursor,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.investment_search_response_200_output_investments_item import InvestmentSearchResponse200OutputInvestmentsItem
        d = dict(src_dict)
        investments = []
        _investments = d.pop("investments")
        for investments_item_data in (_investments):
            investments_item = InvestmentSearchResponse200OutputInvestmentsItem.from_dict(investments_item_data)



            investments.append(investments_item)


        def _parse_next_cursor(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        next_cursor = _parse_next_cursor(d.pop("nextCursor"))


        investment_search_response_200_output = cls(
            investments=investments,
            next_cursor=next_cursor,
        )


        investment_search_response_200_output.additional_properties = d
        return investment_search_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class PeopleSearchCountBodySearchParamsEducationType0AnyOfType0ItemStartedSchoolAtType1WindowType1Method(str, Enum):
    WITHIN = "within"

    def __str__(self) -> str:
        return str(self.value)
